@@ -3,9 +3,9 @@ import sys
 
 sys.path.append ( "./xrecord/" )
 
-from src.db import XRecordDatabase, Record
-from src.sqlite import XRecordSqlite
-from src.mysql import XRecordMySQL
+from src.XRecord.db import XRecordDatabase, Record
+from src.XRecord.sqlite import XRecordSqlite
+from src.XRecord.mysql import XRecordMySQL
 
 db = XRecordSqlite ( name=":memory:" )
 db.CommandQuery ( "CREATE TABLE a(i integer primary key,j,k,l)" )
